@@ -22,11 +22,14 @@ from .component import Component, MetaComponent, abstract
 from .component import implements, implementations, interfacedoc
 from .api import IProcessor
 from .exceptions import Error, PIDError, ApiError
+from .tools.parameters import HasParam
 
 import re
 import numpy
 import uuid
-
+import networkx as nx
+import inspect
+import os
 import gobject
 gobject.threads_init()
 
@@ -44,16 +47,20 @@ class MetaProcessor(MetaComponent):
     valid_id = re.compile("^[a-z][_a-z0-9]*$")
 
     def __new__(cls, name, bases, d):
-        new_class = MetaComponent.__new__(cls, name, bases, d)
+        new_class = super(MetaProcessor, cls).__new__(cls, name, bases, d)
         if new_class in implementations(IProcessor):
             id = str(new_class.id())
             if id in _processors:
                 # Doctest test can duplicate a processor
                 # This can be identify by the conditon "module == '__main__'"
+                new_path = os.path.realpath(inspect.getfile(new_class))
+                id_path = os.path.realpath(inspect.getfile(_processors[id]))
                 if new_class.__module__ == '__main__':
                     new_class = _processors[id]
                 elif _processors[id].__module__ == '__main__':
                     pass
+                elif new_path == id_path:
+                    new_class = _processors[id]
                 else:
                     raise ApiError("%s and %s have the same id: '%s'"
                                    % (new_class.__name__,
@@ -67,14 +74,14 @@ class MetaProcessor(MetaComponent):
         return new_class
 
 
-class Processor(Component):
+class Processor(Component, HasParam):
 
     """Base component class of all processors
 
 
     Attributes:
-              parents :  List of parent Processors that must be processed
-                         before the current Processor
+              parents :  Dictionnary of parent Processors that must be
+                         processed before the current Processor
               pipe :     The ProcessPipe in which the Processor will run
         """
     __metaclass__ = MetaProcessor
@@ -82,14 +89,21 @@ class Processor(Component):
     abstract()
     implements(IProcessor)
 
+    type = ''
+
     def __init__(self):
         super(Processor, self).__init__()
 
-        self.parents = []
+        self.parents = {}
         self.source_mediainfo = None
         self.process_pipe = None
         self.UUID = uuid.uuid4()
 
+        self.input_channels = 0
+        self.input_samplerate = 0
+        self.input_blocksize = 0
+        self.input_stepsize = 0
+
     @interfacedoc
     def setup(self, channels=None, samplerate=None, blocksize=None,
               totalframes=None):
@@ -100,15 +114,23 @@ class Processor(Component):
 
         # If empty Set default values for input_* attributes
         # may be setted by the processor during __init__()
-        if not hasattr(self, 'input_channels'):
+        if not self.input_channels:
             self.input_channels = self.source_channels
-        if not hasattr(self, 'input_samplerate'):
+        if not self.input_samplerate:
             self.input_samplerate = self.source_samplerate
-        if not hasattr(self, 'input_blocksize'):
+        if not self.input_blocksize:
             self.input_blocksize = self.source_blocksize
-        if not hasattr(self, 'input_stepsize'):
+        if not self.input_stepsize:
             self.input_stepsize = self.source_blocksize
 
+        # Check samplerate specification if any
+        if self.force_samplerate:
+            if self.input_samplerate != self.force_samplerate:
+                raise ValueError(
+                    '%s requires %d input sample rate: %d provided' %
+                    (self.__class__.__name__, self.force_samplerate,
+                     self.input_samplerate))
+
     # default channels(), samplerate() and blocksize() implementations returns
     # the source characteristics, but processors may change this behaviour by
     # overloading those methods
@@ -148,12 +170,33 @@ class Processor(Component):
     def uuid(self):
         return str(self.UUID)
 
+    @interfacedoc
+    @classmethod
+    def description(self):
+        try:
+            descr = self.__doc__.lstrip().split('\n')[0]
+        except AttributeError:
+            return '*** NO DESCRIPTION FOR THIS PROCESSOR ***'
+
+        return descr
+
+    @property
+    def force_samplerate(self):
+        return None
+
     def __del__(self):
         self.release()
 
     def __or__(self, other):
         return ProcessPipe(self, other)
 
+    def __eq__(self, other):
+        return (self.id() == other.id() and
+                self.get_parameters() == other.get_parameters())
+
+    def __repr__(self):
+        return '-'.join([self.id(), self.get_parameters()])
+
 
 class FixedSizeInputAdapter(object):
 
@@ -161,9 +204,10 @@ class FixedSizeInputAdapter(object):
     input buffers."""
 
     def __init__(self, buffer_size, channels, pad=False):
-        """Construct a new adapter: buffer_size is the desired buffer size in frames,
-        channels the number of channels, and pad indicates whether the last block should
-        be padded with zeros."""
+        """Construct a new adapter:
+        buffer_size is the desired buffer size in frames,
+        channels the number of channels, and pad indicates whether the last
+        block should be padded with zeros."""
 
         self.buffer = numpy.empty((buffer_size, channels))
         self.buffer_size = buffer_size
@@ -171,8 +215,8 @@ class FixedSizeInputAdapter(object):
         self.pad = pad
 
     def blocksize(self, input_totalframes):
-        """Return the total number of frames that this adapter will output according to the
-        input_totalframes argument"""
+        """Return the total number of frames that this adapter will output
+        according to the input_totalframes argument"""
 
         blocksize = input_totalframes
         if self.pad:
@@ -183,9 +227,11 @@ class FixedSizeInputAdapter(object):
         return blocksize
 
     def process(self, frames, eod):
-        """Returns an iterator over tuples of the form (buffer, eod) where buffer is a
-        fixed-sized block of data, and eod indicates whether this is the last block.
-        In case padding is deactivated the last block may be smaller than the buffer size.
+        """Returns an iterator over tuples of the form (buffer, eod)
+        where buffer is a fixed-sized block of data, and eod indicates whether
+        this is the last block.
+        In case padding is deactivated the last block may be smaller than
+        the buffer size.
         """
         src_index = 0
         remaining = len(frames)
@@ -230,19 +276,40 @@ def get_processor(processor_id):
     """Return a processor by its id"""
     if not processor_id in _processors:
         raise PIDError("No processor registered with id: '%s'"
-                    % processor_id)
+                       % processor_id)
 
     return _processors[processor_id]
 
 
 def list_processors(interface=IProcessor, prefix=""):
     print prefix + interface.__name__
+    if len(prefix):
+        underline_char = '-'
+    else:
+        underline_char = '='
+    print prefix + underline_char * len(interface.__name__)
     subinterfaces = interface.__subclasses__()
     for i in subinterfaces:
         list_processors(interface=i, prefix=prefix + "  ")
     procs = processors(interface, False)
     for p in procs:
-        print prefix + "  %s [%s]" % (p.__name__, p.id())
+        print prefix + "  * %s :" % p.id()
+        print prefix + "    \t\t%s" % p.description()
+
+
+def list_processors_rst(interface=IProcessor, prefix=""):
+    print '\n' + interface.__name__
+    if len(prefix):
+        underline_char = '-'
+    else:
+        underline_char = '='
+    print underline_char * len(interface.__name__) + '\n'
+    subinterfaces = interface.__subclasses__()
+    for i in subinterfaces:
+        list_processors_rst(interface=i, prefix=prefix + " ")
+    procs = processors(interface, False)
+    for p in procs:
+        print prefix + "  * **%s** : %s" % (p.id(), p.description())
 
 
 class ProcessPipe(object):
@@ -251,7 +318,8 @@ class ProcessPipe(object):
 
     Attributes:
         processor: List of all processors in the Process pipe
-        results : Results Container for all the analyzers of the Pipe process
+        results : Dictionnary of Results Container from all the analyzers
+                  in the Pipe process
 """
 
     def __init__(self, *others):
@@ -259,11 +327,78 @@ class ProcessPipe(object):
         self._streamer = None
         self._stream_thread = False
         self._is_running = False
+        self._graph = nx.DiGraph(name='ProcessPipe')
 
         self |= others
 
-        from timeside.analyzer.core import AnalyzerResultContainer
-        self.results = AnalyzerResultContainer()
+        self.results = {}
+
+    def append_processor(self, proc, source_proc=None):
+        "Append a new processor to the pipe"
+        if source_proc is None and len(self.processors):
+            source_proc = self.processors[0]
+
+        if source_proc and not isinstance(source_proc, Processor):
+            raise TypeError('source_proc must be a Processor or None')
+
+        if not isinstance(proc, Processor):
+            raise TypeError('proc must be a Processor or None')
+
+        if proc.type == 'decoder' and len(self.processors):
+            raise ValueError('Only the first processor in a pipe could be a Decoder')
+
+        # TODO : check if the processor is already in the pipe
+        if source_proc:
+            for child in self._graph.neighbors_iter(source_proc.uuid()):
+                child_proc = self._graph.node[child]['processor']
+                if proc == child_proc:
+                    proc.UUID = child_proc.UUID
+                    break
+        if not self._graph.has_node(proc.uuid()):
+            self.processors.append(proc)  # Add processor to the pipe
+            self._graph.add_node(proc.uuid(), processor=proc, id=proc.id())
+            if source_proc:
+                self._graph.add_edge(self.processors[0].uuid(), proc.uuid(),
+                                     type='audio_source')
+            proc.process_pipe = self
+            # Add an edge between each parent and proc
+            for parent in proc.parents.values():
+                    self._graph.add_edge(parent.uuid(), proc.uuid(),
+                                         type='data_source')
+
+    def append_pipe(self, proc_pipe):
+        "Append a sub-pipe to the pipe"
+
+        for proc in proc_pipe.processors:
+            self.append_processor(proc)
+
+    def draw_graph(self):
+        import matplotlib.pyplot as plt
+
+        elarge = [(u, v) for (u, v, d) in self._graph.edges(data=True)
+                  if d['type'] == 'audio_source']
+        esmall = [(u, v) for (u, v, d) in self._graph.edges(data=True)
+                  if d['type'] == 'data_source']
+
+        pos = nx.shell_layout(self._graph)  # positions for all nodes
+
+        # nodes
+        nx.draw_networkx_nodes(self._graph, pos, node_size=700)
+
+        # edges
+        nx.draw_networkx_edges(self._graph, pos, edgelist=elarge,
+                               arrows=True)
+        nx.draw_networkx_edges(self._graph, pos, edgelist=esmall,
+                               alpha=0.5, edge_color='b',
+                               style='dashed', arrows=True)
+
+        # labels
+        labels = {node: repr(self._graph.node[node]['processor']) for node in self._graph.nodes()}
+        nx.draw_networkx_labels(self._graph, pos, labels, font_size=20,
+                                font_family='sans-serif')
+
+        plt.axis('off')
+        plt.show()  # display
 
     def __or__(self, other):
         self |= other
@@ -271,18 +406,18 @@ class ProcessPipe(object):
 
     def __ior__(self, other):
         if isinstance(other, Processor):
-            for parent in other.parents:
+            for parent in other.parents.values():
                 self |= parent
-            self.processors.append(other)
-            other.process_pipe = self
+            self.append_processor(other)
+
         elif isinstance(other, ProcessPipe):
-            self.processors.extend(other.processors)
+            self.append_pipe(other)
         else:
             try:
                 iter(other)
             except TypeError:
-                raise Error(
-                    "Can not add this type of object to a pipe: %s", str(other))
+                raise Error("Can not add this type of object to a pipe: %s",
+                            str(other))
 
             for item in other:
                 self |= item
@@ -302,6 +437,21 @@ class ProcessPipe(object):
 
         source = self.processors[0]
         items = self.processors[1:]
+
+        # Check if any processor in items need to force the samplerate
+        force_samplerate = set([item.force_samplerate for item in items
+                                if item.force_samplerate])
+        if force_samplerate:
+            if len(force_samplerate) > 1:
+                raise(ValueError,
+                      "Some processors specify different samplerate")
+            force_samplerate = force_samplerate.pop()
+
+            if samplerate and samplerate != force_samplerate:
+                raise(ValueError, "A processor try to force the samplerate")
+
+            samplerate = force_samplerate
+
         source.setup(channels=channels, samplerate=samplerate,
                      blocksize=blocksize)
         source.SIG_STOP = False
@@ -327,7 +477,7 @@ class ProcessPipe(object):
 
         eod = False
 
-        if source.id() == 'gst_live_dec':
+        if source.id() == 'live_decoder':
             # Set handler for Interruption signal
             import signal
 
@@ -341,7 +491,7 @@ class ProcessPipe(object):
             for item in items:
                 frames, eod = item.process(frames, eod)
 
-        if source.id() == 'gst_live_dec':
+        if source.id() == 'live_decoder':
             # Restore default handler for Interruption signal
             signal.signal(signal.SIGINT, signal.SIG_DFL)
 
@@ -354,7 +504,6 @@ class ProcessPipe(object):
         # Release processors
         for item in items:
             item.release()
-            self.processors.remove(item)
 
         self._is_running = False
 
