@@ -26,11 +26,13 @@ from timeside.api import IEncoder
 
 class VorbisEncoder(GstEncoder):
 
-    """ gstreamer-based OGG Vorbis encoder """
+    """OGG Vorbis encoder based on Gstreamer"""
+
     implements(IEncoder)
 
     @interfacedoc
-    def setup(self, channels=None, samplerate=None, blocksize=None, totalframes=None):
+    def setup(self, channels=None, samplerate=None, blocksize=None,
+              totalframes=None):
         super(VorbisEncoder, self).setup(
             channels, samplerate, blocksize, totalframes)
         self.pipe = ''' appsrc name=src
@@ -55,12 +57,7 @@ class VorbisEncoder(GstEncoder):
     @staticmethod
     @interfacedoc
     def id():
-        return "gst_vorbis_enc"
-
-    @staticmethod
-    @interfacedoc
-    def description():
-        return "Vorbis GStreamer based encoder"
+        return "vorbis_encoder"
 
     @staticmethod
     @interfacedoc
