@@ -17,13 +17,19 @@
 # You should have received a copy of the GNU General Public License
 # along with TimeSide.  If not, see <http://www.gnu.org/licenses/>.
 
+
 class Error(Exception):
+
     """Exception base class for errors in TimeSide."""
 
+
 class ApiError(Exception):
+
     """Exception base class for errors in TimeSide."""
 
+
 class SubProcessError(Error):
+
     """Exception for reporting errors from a subprocess"""
 
     def __init__(self, message, command, subprocess):
@@ -32,10 +38,18 @@ class SubProcessError(Error):
         self.subprocess = subprocess
 
     def __str__(self):
-        if self.subprocess.stderr != None:
+        if self.subprocess.stderr is not None:
             error = self.subprocess.stderr.read()
         else:
             error = ''
         return "%s ; command: %s; error: %s" % (self.message,
                                                 self.command,
                                                 error)
+
+
+class PIDError(KeyError):
+    "Exception for reporting missing Processor ID in registered processors"
+
+
+class VampImportError(ImportError):
+    "Can't import module depending on Vamp because vamp host is missing"
